==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/desktopvirtualization/kotlin/inputs/AppAttachPackagePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.desktopvirtualization.kotlin.inputs

import com.pulumi.azurenative.desktopvirtualization.inputs.AppAttachPackagePropertiesArgs.builder
import com.pulumi.azurenative.desktopvirtualization.kotlin.enums.FailHealthCheckOnStagingFailure
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Schema for App Attach Package properties.
 * @property failHealthCheckOnStagingFailure Parameter indicating how the health check should behave if this package fails staging
 * @property hostPoolReferences List of Hostpool resource Ids.
 * @property image Detailed properties for App Attach Package
 * @property keyVaultURL URL of keyvault location to store certificate
 */
public data class AppAttachPackagePropertiesArgs(
    public val failHealthCheckOnStagingFailure:
    Output<Either<String, FailHealthCheckOnStagingFailure>>? = null,
    public val hostPoolReferences: Output<List<String>>? = null,
    public val image: Output<AppAttachPackageInfoPropertiesArgs>? = null,
    public val keyVaultURL: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.desktopvirtualization.inputs.AppAttachPackagePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.desktopvirtualization.inputs.AppAttachPackagePropertiesArgs =
        com.pulumi.azurenative.desktopvirtualization.inputs.AppAttachPackagePropertiesArgs.builder()
            .failHealthCheckOnStagingFailure(
                failHealthCheckOnStagingFailure?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .hostPoolReferences(hostPoolReferences?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .image(image?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .keyVaultURL(keyVaultURL?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AppAttachPackagePropertiesArgs].
 */
@PulumiTagMarker
public class AppAttachPackagePropertiesArgsBuilder internal constructor() {
    private var failHealthCheckOnStagingFailure:
        Output<Either<String, FailHealthCheckOnStagingFailure>>? = null

    private var hostPoolReferences: Output<List<String>>? = null

    private var image: Output<AppAttachPackageInfoPropertiesArgs>? = null

    private var keyVaultURL: Output<String>? = null

    /**
     * @param value Parameter indicating how the health check should behave if this package fails staging
     */
    @JvmName("ixxoqdpcveygajig")
    public suspend
    fun failHealthCheckOnStagingFailure(`value`: Output<Either<String, FailHealthCheckOnStagingFailure>>) {
        this.failHealthCheckOnStagingFailure = value
    }

    /**
     * @param value List of Hostpool resource Ids.
     */
    @JvmName("pwlprfxherwftsgb")
    public suspend fun hostPoolReferences(`value`: Output<List<String>>) {
        this.hostPoolReferences = value
    }

    @JvmName("txwbbityvbarbnkp")
    public suspend fun hostPoolReferences(vararg values: Output<String>) {
        this.hostPoolReferences = Output.all(values.asList())
    }

    /**
     * @param values List of Hostpool resource Ids.
     */
    @JvmName("rcfiwstcctyuebfq")
    public suspend fun hostPoolReferences(values: List<Output<String>>) {
        this.hostPoolReferences = Output.all(values)
    }

    /**
     * @param value Detailed properties for App Attach Package
     */
    @JvmName("paaamteogsguorec")
    public suspend fun image(`value`: Output<AppAttachPackageInfoPropertiesArgs>) {
        this.image = value
    }

    /**
     * @param value URL of keyvault location to store certificate
     */
    @JvmName("dtujtetuhfxicfao")
    public suspend fun keyVaultURL(`value`: Output<String>) {
        this.keyVaultURL = value
    }

    /**
     * @param value Parameter indicating how the health check should behave if this package fails staging
     */
    @JvmName("kvvsnlahlkkquyxa")
    public suspend
    fun failHealthCheckOnStagingFailure(`value`: Either<String, FailHealthCheckOnStagingFailure>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.failHealthCheckOnStagingFailure = mapped
    }

    /**
     * @param value Parameter indicating how the health check should behave if this package fails staging
     */
    @JvmName("gyweroloyvdobtlb")
    public fun failHealthCheckOnStagingFailure(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FailHealthCheckOnStagingFailure>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failHealthCheckOnStagingFailure = mapped
    }

    /**
     * @param value Parameter indicating how the health check should behave if this package fails staging
     */
    @JvmName("dyrdedxlwxrfuqry")
    public fun failHealthCheckOnStagingFailure(`value`: FailHealthCheckOnStagingFailure) {
        val toBeMapped = Either.ofRight<String, FailHealthCheckOnStagingFailure>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failHealthCheckOnStagingFailure = mapped
    }

    /**
     * @param value List of Hostpool resource Ids.
     */
    @JvmName("lmfwmugtcrwjbpyn")
    public suspend fun hostPoolReferences(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostPoolReferences = mapped
    }

    /**
     * @param values List of Hostpool resource Ids.
     */
    @JvmName("ubqgodvutldwfoor")
    public suspend fun hostPoolReferences(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hostPoolReferences = mapped
    }

    /**
     * @param value Detailed properties for App Attach Package
     */
    @JvmName("oxmqmxxbfmjoxatv")
    public suspend fun image(`value`: AppAttachPackageInfoPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.image = mapped
    }

    /**
     * @param argument Detailed properties for App Attach Package
     */
    @JvmName("neuqhsnmwddkoimm")
    public suspend fun image(argument: suspend AppAttachPackageInfoPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = AppAttachPackageInfoPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.image = mapped
    }

    /**
     * @param value URL of keyvault location to store certificate
     */
    @JvmName("mfydadkfjsjyqbfl")
    public suspend fun keyVaultURL(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultURL = mapped
    }

    internal fun build(): AppAttachPackagePropertiesArgs = AppAttachPackagePropertiesArgs(
        failHealthCheckOnStagingFailure = failHealthCheckOnStagingFailure,
        hostPoolReferences = hostPoolReferences,
        image = image,
        keyVaultURL = keyVaultURL,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/desktopvirtualization/kotlin/inputs/AppAttachPackagePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.desktopvirtualization.kotlin.inputs

import com.pulumi.azurenative.desktopvirtualization.inputs.AppAttachPackagePropertiesArgs.builder
import com.pulumi.azurenative.desktopvirtualization.kotlin.enums.FailHealthCheckOnStagingFailure
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Schema for App Attach Package properties.
 * @property failHealthCheckOnStagingFailure Parameter indicating how the health check should behave if this package fails staging
 * @property hostPoolReferences List of Hostpool resource Ids.
 * @property image Detailed properties for App Attach Package
 * @property keyVaultURL URL of keyvault location to store certificate
 */
public data class AppAttachPackagePropertiesArgs(
    public val failHealthCheckOnStagingFailure:
    Output<Either<String, FailHealthCheckOnStagingFailure>>? = null,
    public val hostPoolReferences: Output<List<String>>? = null,
    public val image: Output<AppAttachPackageInfoPropertiesArgs>? = null,
    public val keyVaultURL: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.desktopvirtualization.inputs.AppAttachPackagePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.desktopvirtualization.inputs.AppAttachPackagePropertiesArgs =
        com.pulumi.azurenative.desktopvirtualization.inputs.AppAttachPackagePropertiesArgs.builder()
            .failHealthCheckOnStagingFailure(
                failHealthCheckOnStagingFailure?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .hostPoolReferences(hostPoolReferences?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .image(image?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .keyVaultURL(keyVaultURL?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AppAttachPackagePropertiesArgs].
 */
@PulumiTagMarker
public class AppAttachPackagePropertiesArgsBuilder internal constructor() {
    private var failHealthCheckOnStagingFailure:
        Output<Either<String, FailHealthCheckOnStagingFailure>>? = null

    private var hostPoolReferences: Output<List<String>>? = null

    private var image: Output<AppAttachPackageInfoPropertiesArgs>? = null

    private var keyVaultURL: Output<String>? = null

    /**
     * @param value Parameter indicating how the health check should behave if this package fails staging
     */
    @JvmName("xsaokfmykswwhgle")
    public suspend
    fun failHealthCheckOnStagingFailure(`value`: Output<Either<String, FailHealthCheckOnStagingFailure>>) {
        this.failHealthCheckOnStagingFailure = value
    }

    /**
     * @param value List of Hostpool resource Ids.
     */
    @JvmName("pgsldjpcyffrhibx")
    public suspend fun hostPoolReferences(`value`: Output<List<String>>) {
        this.hostPoolReferences = value
    }

    @JvmName("qeiicihjecgonbad")
    public suspend fun hostPoolReferences(vararg values: Output<String>) {
        this.hostPoolReferences = Output.all(values.asList())
    }

    /**
     * @param values List of Hostpool resource Ids.
     */
    @JvmName("ohtgfbsodepdqrxj")
    public suspend fun hostPoolReferences(values: List<Output<String>>) {
        this.hostPoolReferences = Output.all(values)
    }

    /**
     * @param value Detailed properties for App Attach Package
     */
    @JvmName("xfqxcqjummjsafdt")
    public suspend fun image(`value`: Output<AppAttachPackageInfoPropertiesArgs>) {
        this.image = value
    }

    /**
     * @param value URL of keyvault location to store certificate
     */
    @JvmName("ecxapkymaxjpdyws")
    public suspend fun keyVaultURL(`value`: Output<String>) {
        this.keyVaultURL = value
    }

    /**
     * @param value Parameter indicating how the health check should behave if this package fails staging
     */
    @JvmName("xwnuuppgfjebwcvx")
    public suspend
    fun failHealthCheckOnStagingFailure(`value`: Either<String, FailHealthCheckOnStagingFailure>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.failHealthCheckOnStagingFailure = mapped
    }

    /**
     * @param value Parameter indicating how the health check should behave if this package fails staging
     */
    @JvmName("klkkbxbekfhjnsds")
    public fun failHealthCheckOnStagingFailure(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FailHealthCheckOnStagingFailure>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failHealthCheckOnStagingFailure = mapped
    }

    /**
     * @param value Parameter indicating how the health check should behave if this package fails staging
     */
    @JvmName("bjgvlcjltmjadfwk")
    public fun failHealthCheckOnStagingFailure(`value`: FailHealthCheckOnStagingFailure) {
        val toBeMapped = Either.ofRight<String, FailHealthCheckOnStagingFailure>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failHealthCheckOnStagingFailure = mapped
    }

    /**
     * @param value List of Hostpool resource Ids.
     */
    @JvmName("dowwyuhjauvlycpu")
    public suspend fun hostPoolReferences(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostPoolReferences = mapped
    }

    /**
     * @param values List of Hostpool resource Ids.
     */
    @JvmName("qyfxhothoqmttvlh")
    public suspend fun hostPoolReferences(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hostPoolReferences = mapped
    }

    /**
     * @param value Detailed properties for App Attach Package
     */
    @JvmName("vwhhvdjrjhqwowkf")
    public suspend fun image(`value`: AppAttachPackageInfoPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.image = mapped
    }

    /**
     * @param argument Detailed properties for App Attach Package
     */
    @JvmName("lhbhqyqpxyaofgjv")
    public suspend fun image(argument: suspend AppAttachPackageInfoPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = AppAttachPackageInfoPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.image = mapped
    }

    /**
     * @param value URL of keyvault location to store certificate
     */
    @JvmName("ayfmycwlrdnacyae")
    public suspend fun keyVaultURL(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultURL = mapped
    }

    internal fun build(): AppAttachPackagePropertiesArgs = AppAttachPackagePropertiesArgs(
        failHealthCheckOnStagingFailure = failHealthCheckOnStagingFailure,
        hostPoolReferences = hostPoolReferences,
        image = image,
        keyVaultURL = keyVaultURL,
    )
}
